package coloreti.data;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.image.BufferedImage;
import java.awt.image.CropImageFilter;
import java.awt.image.FilteredImageSource;
import java.io.Serializable;

import coloreti.gui.GuiBase;
import coloreti.interfaces.Displayable;

/**
 * This class represents a gem object.
 * Note that this Displayable's point of reference is its center.
 * @author ctheng
 *
 */
public class Gem implements Displayable, Serializable {

	private float px, py;
	private float dx, dy;
	private int color;
	
	public final static Color[] gemColors = new Color[] {
		Color.red,
		Color.cyan,
		Color.orange,
		Color.magenta,
		Color.green,
		Color.white,
		new Color(0, 0, 128)
	};
	
	public final static String GEM_SPRITE_FILENAME = "sprites/gems.gif";
	public final static BufferedImage GEM_SPRITES = GuiBase.loadBufferedImage(GEM_SPRITE_FILENAME);
	
	public final static int NUM_GEMS = gemColors.length;
	public final static int GEM_RADIUS = 15;
	
	public Gem (float x, float y, int color)
	{
		this.px = x;
		this.py = y;
		this.color = color;
	}

	/**
	 * @return the x
	 */
	public float getX() {
		return px;
	}



	/**
	 * @return the y
	 */
	public float getY() {
		return py;
	}



	/**
	 * @return the dx
	 */
	public float getDx() {
		return dx;
	}



	/**
	 * @return the dy
	 */
	public float getDy() {
		return dy;
	}

	/**
	 * Modifies the velocity of the gem by dx, dy
	 * @param dx The change in x velocity
	 * @param dy The change in y velocity
	 */
	public void adjustVelocity(float dx, float dy)
	{
		this.dx += dx;
		this.dy += dy;
	}
	
	/**
	 * Sets velocity of this object to 0
	 */
	public void stopMotion()
	{
		dx = 0;
		dy = 0;
	}

	/**
	 * @return the color
	 */
	public int getColor() {
		return color;
	}


	/*
	 * (non-Javadoc)
	 * @see coloreti.Displayable#drawComponent(java.awt.Graphics2D, int, int)
	 */
	public void drawComponent(Graphics2D g, int x, int y)
	{
		Image gem = getGemImage(color);
		
		g.drawImage(gem, Math.round(px - GEM_RADIUS) + x, Math.round(py - GEM_RADIUS) + y, null);
	}

	/*
	 * (non-Javadoc)
	 * @see coloreti.Displayable#update(long)
	 */
	public void update(long elapsedTime)
	{

	}
	
	public static Image getGemImage(int color)
	{
		return GEM_SPRITES.getSubimage(color * GEM_RADIUS * 2, 0, GEM_RADIUS *2, GEM_RADIUS * 2);
	}

}
