package coloreti.gui;

import java.awt.*;
import java.awt.event.KeyEvent;
import java.awt.image.*;
import java.awt.BorderLayout;

import javax.swing.JFrame;
import javax.swing.JOptionPane;


import java.util.*;

import coloreti.GameController;
import coloreti.data.Board;
import coloreti.data.Gem;
import coloreti.data.Player;
import coloreti.interfaces.Displayable;
import coloreti.util.Pair;

public class Lobby implements Displayable{
	
	private static final String SPLASH_FILENAME = "textures/splash.jpg";
	public static final int BUTTON_CONNECT = 1;
	public static final int BUTTON_READY = 2;
	public static final int BUTTON_READY_PRESSED = 3;
	private static final int MAX_CHAT_LINES = 20;
	private static final int MAX_PLAYERS = 6;
	
	private Image bgImage;

	private int height, width;
	
	//info of current player
	private String playerName, hostName, port;
	
	//state of lobby
	private GameController parent;
	private ArrayList<String> listOfPlayers;
	private ArrayList<String> chatLines;
	private int buttonState;
	//is the player connected??
	private boolean isConnected;
	//is the player in the chat box?
	private boolean isChat;
	//the current line typed
	private String currChatLine;
	/** The position of the cursor within the line */
	private int cursorPos;
	/** The font we are using in the chat window */
	private Font chatFont;
	
	private long timer;
	
	public Lobby(GameController parent, int width, int height)
	{
		this.parent = parent;
		if(listOfPlayers==null){
			listOfPlayers = new ArrayList<String>();
		}
		if(chatLines == null){
			chatLines = new ArrayList<String>();			
		}

		this.width = width;
		this.height = height;
		//loads bg image
		bgImage = GuiBase.loadImage(SPLASH_FILENAME);
		
		buttonState = BUTTON_CONNECT;
		currChatLine = "";
		cursorPos = 0;
		timer = 0;
		isChat = true;
		isConnected = false;
		chatFont = new Font("Verdana", Font.PLAIN, 12);
		
	}
	
	public void drawComponent(Graphics2D g, int x, int y){
		
		g.setBackground(new Color(192,192,192));
		g.clearRect(0, 0, width, height);
		int buttonWidth = 100;
		int buttonHeight = 50;
		g.setFont(new Font("Verdana", Font.BOLD, 14));

		//draws button
		switch (buttonState){
		case BUTTON_CONNECT:
			g.drawImage(bgImage, x, y, null);
			g.setColor(new Color(10,150,150));
			g.fillRect(width-buttonWidth-10, height-buttonHeight-10, buttonWidth, buttonHeight);
			g.setColor(new Color(0,0,0));
			g.drawString("Continue", width-buttonWidth, height-buttonHeight/2);
			break;
		case BUTTON_READY:
			g.setColor(new Color(10,200,10));
			g.fillRect(width-buttonWidth-10, height-buttonHeight-10, buttonWidth, buttonHeight);
			g.setColor(new Color(0,0,0));
			g.drawString("Ready!", width-buttonWidth, height-buttonHeight/2);		
			break;
		case BUTTON_READY_PRESSED:
			g.setColor(new Color(200,10,10));
			g.fillRect(width-buttonWidth-10, height-buttonHeight-10, buttonWidth, buttonHeight);
			g.setColor(new Color(100,100,100));
			g.drawString("Ready!", width-buttonWidth, height-buttonHeight/2);		
			break;
		
		}
		//the -10 is to pad it to look nice

		
		if(isConnected){
			
			/*CHAT STUFF*/
			int chatBoxY = 100;
			int	chatBoxX = 10;
			int chatBoxHeight = MAX_CHAT_LINES * 20;
			int chatBoxWidth = 400;
			g.setFont(chatFont);
			
			g.setColor(new Color(0,0,0));
			//chat contents
			g.drawRect(chatBoxX, chatBoxY, chatBoxWidth, chatBoxHeight);
			
			//current input line
			g.drawRect(chatBoxX, chatBoxY+chatBoxHeight+5, chatBoxWidth, 20);
			g.drawString(currChatLine, chatBoxX+3, chatBoxY+chatBoxHeight+20);
			// draw blinking cursor
			
			if (isChat && timer % 1000 > 500)
			{
				int xoffset = g.getFontMetrics().stringWidth(currChatLine.substring(0, cursorPos)) + 1;
				g.drawLine(chatBoxX + 3 + xoffset, chatBoxY + chatBoxHeight + 6, chatBoxX + 3 + xoffset,
						chatBoxY + chatBoxHeight + 24);
			}
			for(int i = 0; i < chatLines.size(); i++)
			{	
				g.drawString(chatLines.get(i), chatBoxX+3, chatBoxY + 20*(i + 1) - 2);
			}
			/*END OF CHAT STUFF*/
			
			/*LIST OF CONNECTED PLAYERS*/
			int playerBoxX = 20 + chatBoxWidth;
			int playerBoxY = 405;
			int playerBoxHeight = MAX_PLAYERS * 20;
			int playerBoxWidth = 370;
			g.setFont(new Font("Verdana", Font.BOLD,13));
			g.drawRect(playerBoxX, playerBoxY, playerBoxWidth, playerBoxHeight);
			g.drawString("Online players: ", playerBoxX+3, playerBoxY-3);
			
			int nameCount=0;
			for(int i = 0; i < listOfPlayers.size(); i++){
				String name = listOfPlayers.get(i);
				if (name.equals(playerName))
				{
					g.setColor(new Color(0, 192, 0));
				}
				else
				{
					g.setColor(Color.black);
				}
				
				g.drawString(name, playerBoxX+3, playerBoxY + 20*(nameCount+1));
				nameCount++;
			}		
			/*END OF LIST OF CONNECTED PLAYERS*/
			
		}

			
		
	}
	
	public void update(long elapsedTime) {
		// TODO Auto-generated method stub
		timer += elapsedTime;
		while (chatLines.size() > MAX_CHAT_LINES)
		{
			chatLines.remove(0);
		}
	}

	public String getPlayerName() {
		return playerName;
	}

	public void setPlayerName(String playerName) {
		this.playerName = playerName;
	}

	public String getHostName() {
		return hostName;
	}

	public void setHostName(String hostName) {
		this.hostName = hostName;
	}

	public String getPort() {
		return port;
	}

	public void setPort(String port) {
		this.port = port;
	}

	public ArrayList<String> getListOfPlayers() {
		return listOfPlayers;
	}

	public void setListOfPlayers(ArrayList<String> listOfPlayers) {
		this.listOfPlayers = listOfPlayers;
	}

	public ArrayList<String> getChatLines() {
		return chatLines;
	}

	public void setChatLines(ArrayList<String> chatLines) {
		this.chatLines = chatLines;
	}

	public int getButtonState() {
		return buttonState;
	}

	public void setButtonState(int buttonState) {
		this.buttonState = buttonState;
	}

	public boolean isConnected() {
		return isConnected;
	}

	public void setConnected(boolean isConnected) {
		this.isConnected = isConnected;
	}

	public boolean isChat() {
		return isChat;
	}

	public void setChat(boolean isChat) {
		this.isChat = isChat;
	}

	public String getCurrChatLine() {
		return currChatLine;
	}

	public void setCurrChatLine(String currChatLine) {
		this.currChatLine = currChatLine;
	}
	
	public void leftMouseClicked(int x, int y)
	{

		//if click is within chat box
		if(isConnected && x > 10 && x < 410 && y > 505 && y < 525)
		{
			isChat = true;
		}
		else
		{
			isChat = false;
		}
		
		//if click is within button
		if(x >= 690 && x < 790 && y >= 540 && y < 590)
		{
			//if connection is done
			if(buttonState == BUTTON_CONNECT)
			{
				parent.lobbyButtonPressed(BUTTON_CONNECT);
			}
			else if(buttonState == BUTTON_READY)
			{
				parent.lobbyButtonPressed(BUTTON_READY);
			}
			else
			{
				parent.lobbyButtonPressed(BUTTON_READY_PRESSED);
			}
		}
		
	}
	
	public void keyPressed(KeyEvent e)
	{
		if (isChat)
		{
			switch (e.getKeyCode())
			{
			case KeyEvent.VK_ENTER:
				parent.sendTextMessage(currChatLine);
				currChatLine = "";
				cursorPos = 0;
				break;
			case KeyEvent.VK_BACK_SPACE:
				if (cursorPos > 0)
				{
					currChatLine = currChatLine.substring(0, cursorPos - 1) +
						currChatLine.substring(cursorPos, currChatLine.length());
					cursorPos--;
				}
				break;
			case KeyEvent.VK_LEFT:
				cursorPos = Math.max(cursorPos - 1, 0);
				break;
			case KeyEvent.VK_RIGHT:
				cursorPos = Math.min(cursorPos + 1, currChatLine.length());
				break;
			case KeyEvent.VK_DELETE:
				if (cursorPos < currChatLine.length())
				{
					currChatLine = currChatLine.substring(0, cursorPos) + 
						currChatLine.substring(cursorPos+1, currChatLine.length());
				}
				break;
			case KeyEvent.VK_HOME:
				cursorPos = 0;
				break;
			case KeyEvent.VK_END:
				cursorPos = currChatLine.length();
				break;
			case KeyEvent.VK_SHIFT:
			case KeyEvent.VK_CONTROL:
			case KeyEvent.VK_ALT:
				break;
			default:
				char q = e.getKeyChar();
				if (q >= 32 && q != KeyEvent.CHAR_UNDEFINED)
				{
					currChatLine = currChatLine.substring(0, cursorPos) + q + 
						currChatLine.substring(cursorPos, currChatLine.length());
					cursorPos++;
				}
			}
			
		}
	}
	 

}

