package coloreti.gui;

import java.awt.*;
import java.awt.image.BufferedImage;
import java.util.Arrays;

import coloreti.data.Player;
import coloreti.gui.GuiBase;
import coloreti.interfaces.Displayable;

public class Overlay implements Displayable{
	
	private static final String OVERLAY_FILENAME = "sprites/overlay.png";
	public static final int NO_OVERLAY = -1;
	public static final int CAST_OVERLAY = 0;
	public static final int FIRE_OVERLAY = 1;
	public static final int FREEZE_OVERLAY = 2;
	public static final int HASTE_OVERLAY = 3;
	public static final int CONFUSE_OVERLAY = 4;
	public static final int LIGHTNING_OVERLAY = 5;
	
	private static final long TIME_PER_ANIMATION=30;
	private static final int MAX_OVERLAY_X = 5;
	private static final int MAX_OVERLAY_Y = 5;
	
	
	private static BufferedImage overlays;
	
	private int currentOverlay;
	private int overlayX,overlayY;
	private Player player;
	private long animationTime;
	
	private static final int[][] ANIMATION_LENGTH = {
		{200,200,200,200,200},
		{200,200,200,200,200},
		{1000,1000,1000,1500,1500},
		{100, 200, 200, 200, 100},
		{200, 200, 200, 200, 200},
		{200, 200, 200, 200, 3000}	
	};
	
	
	public Overlay(Player p)
	{
		player = p;
		overlays = GuiBase.loadBufferedImage(OVERLAY_FILENAME);
		currentOverlay = -1;
		animationTime = 0;
	}


	public void drawComponent(Graphics2D g, int x, int y)
	{
		if(currentOverlay == NO_OVERLAY)
		{
			return;
		}		

		overlayY = currentOverlay;
		int subX, subY;
		subX = overlayX * 100;
		subY = overlayY * 100;
		
		if(currentOverlay == FREEZE_OVERLAY)
		{
			Image subImage = overlays.getSubimage(subX, subY, 100, 100);
			g.drawImage(subImage, Math.round(player.getX() + x) - 50, 
					Math.round(player.getY() + y) - 60, null);
		}
		else if (currentOverlay == FIRE_OVERLAY || currentOverlay == CAST_OVERLAY)
		{
			Image subImage = overlays.getSubimage(subX, subY, 100, 100);
			g.drawImage(subImage, Math.round(player.getX() + x) - 50,
					Math.round(player.getY() + y) - 50, null);
		}
		else if (currentOverlay == HASTE_OVERLAY || currentOverlay == CONFUSE_OVERLAY)
		{
			Image subImage = overlays.getSubimage(subX, subY, 100, 100);
			g.drawImage(subImage, Math.round(player.getX() + x) - 50,
					Math.round(player.getY() + y) - 100, null);
		}
		else if (currentOverlay == LIGHTNING_OVERLAY)
		{
			Image subImage = overlays.getSubimage(subX, subY, 100, 100);
			g.drawImage(subImage, Math.round(player.getX() + x) - 50,
					Math.round(player.getY() + y) - 80, null);
		}
	}
	
	public void update(long elapsedTime)
	{
		
		if (currentOverlay == NO_OVERLAY)
		{
			return;
		}
		
		animationTime+=elapsedTime;
		if(animationTime >= ANIMATION_LENGTH[overlayY][overlayX])
		{
			int tmp = ANIMATION_LENGTH[overlayY][overlayX];
			overlayX++;
			if(overlayX == MAX_OVERLAY_X)
			{
				overlayX=0;
			}
			animationTime-= tmp;
		}
	}
	
	public void castOverlay (int overlay)
	{
		overlayX = 0;
		animationTime = 0;
		currentOverlay = overlay;
		overlayY = currentOverlay;
	}

}


