package coloreti.network.messages;

/**
 * A game info message is sent from the server to the clients to inform them
 * of happenings in-game
 * @author ctheng
 *
 */
public class GameInfoMessage extends Message
{
	
	public enum GameInfoType
	{
		GEM_CREATED,
		GEM_PICKED_UP,
		ATTACK_FIRED
	}
	
	private GameInfoType type;
	private float x, y;
	private float facing;
	/** In the case of Gem created, data1 is the color, otherwise, it's the activating
	 * player
	 */
	private int data1;
	/** Unused for GEM_CREATED
	 *  For GEM_PICKED_UP, this is the gem's index
	 *  For ATTACK_FIRED, this is a bit representation of the attack
	 */
	private int data2;
	/**
	 * For gem picked up, this is the gem's color
	 */
	private int data3;
	
	public GameInfoMessage(int senderId, GameInfoType type)
	{
		super(senderId);
		this.type = type;
	}

	/**
	 * @return the type
	 */
	public GameInfoType getType() {
		return type;
	}

	/**
	 * @return the x
	 */
	public float getX() {
		return x;
	}

	/**
	 * @param x the x to set
	 */
	public void setX(float x) {
		this.x = x;
	}

	/**
	 * @return the y
	 */
	public float getY() {
		return y;
	}

	/**
	 * @param y the y to set
	 */
	public void setY(float y) {
		this.y = y;
	}

	/**
	 * @return the data1
	 */
	public int getData1() {
		return data1;
	}

	/**
	 * @param data1 the data1 to set
	 */
	public void setData1(int data1) {
		this.data1 = data1;
	}

	/**
	 * @return the data2
	 */
	public int getData2() {
		return data2;
	}

	/**
	 * @param data2 the data2 to set
	 */
	public void setData2(int data2) {
		this.data2 = data2;
	}

	/**
	 * @param facing the facing to set
	 */
	public void setFacing(float facing) {
		this.facing = facing;
	}

	/**
	 * @return the facing
	 */
	public float getFacing() {
		return facing;
	}

	/**
	 * @param data3 the data3 to set
	 */
	public void setData3(int data3) {
		this.data3 = data3;
	}

	/**
	 * @return the data3
	 */
	public int getData3() {
		return data3;
	}
	
	
	
}
