package coloreti.network.messages;

import java.awt.Polygon;
import java.util.ArrayList;

import coloreti.data.Gem;
import coloreti.data.PlayerInitData;

/**
 * A game start message is sent by the server to all clients to signify that the game
 * is starting. The message contains the initial setup of the board as well as each
 * player's identity.
 * @author ctheng
 *
 */
public class GameStartMessage extends Message 
{
	private int receiverId;
	private ArrayList<PlayerInitData> playerData;
	private ArrayList<Gem> gemData;
	private ArrayList<Polygon> boundaries;
	private int width, height;
	private int totalTime;
	
	public GameStartMessage(int senderId, int receiverId) 
	{
		super(senderId);
		this.receiverId = receiverId;
		playerData = new ArrayList<PlayerInitData>();
		gemData = new ArrayList<Gem>();
		boundaries = new ArrayList<Polygon>();
	}

	/**
	 * @return the width
	 */
	public int getWidth() {
		return width;
	}

	/**
	 * @param width the width to set
	 */
	public void setWidth(int width) {
		this.width = width;
	}

	/**
	 * @return the height
	 */
	public int getHeight() {
		return height;
	}

	/**
	 * @param height the height to set
	 */
	public void setHeight(int height) {
		this.height = height;
	}

	/**
	 * Sets the receiver id
	 * @param id The id to set
	 */
	public void setReceiverId(int id)
	{
		receiverId = id;
	}
	
	/**
	 * @return the receiverId
	 */
	public int getReceiverId() {
		return receiverId;
	}

	/**
	 * @return the playerData
	 */
	public ArrayList<PlayerInitData> getPlayerData() {
		return playerData;
	}

	/**
	 * @return the gemData
	 */
	public ArrayList<Gem> getGemData() {
		return gemData;
	}
	
	/**
	 * @return the boundaries
	 */
	public ArrayList<Polygon> getBoundaries()
	{
		return boundaries;
	}

	/**
	 * @param totalTime the totalTime to set
	 */
	public void setTotalTime(int totalTime) {
		this.totalTime = totalTime;
	}

	/**
	 * @return the totalTime
	 */
	public int getTotalTime() {
		return totalTime;
	}
	
	
}
