package coloreti.network.messages;

public class InitialMessage extends Message 
{
	/**
	 * Represents the type of the initialization message
	 * @author ctheng
	 *
	 */
	public enum InitialMessageType
	{
		/** This initialization message contains the client's name */
		NAME_SEND("Name send"),
		/** This initialization message welcomes the client to the server, sends a list
		 * of clients already connected */
		WELCOME("Welcome"),
		/** This initialization message signals that a client has joined the lobby */
		CLIENT_JOINED("Client joined"),
		/** This initialization message signals that a client has left the lobby */
		CLIENT_LEFT("Client left"),
		/** This initialization message signals that a client is ready */
		READY("Ready");
		
		private String info;
		
		InitialMessageType (String info)
		{
			this.info = info;
		}
		
		public String getInfo()
		{
			return info;
		}
	}
	
	private String data;
	private InitialMessageType type;
	
	public InitialMessage(int id, InitialMessageType type)
	{
		super(id);
		this.type = type;
	}

	/**
	 * Sets the data enclosed within this message
	 * @param data the data to set
	 */
	public void setData(String data) 
	{
		this.data = data;
	}

	/**
	 * Gets the data enclosed within this message
	 * @return the data within this message
	 */
	public String getData() 
	{
		return data;
	}

	/**
	 * Gets the type of the message
	 * @return the type of the message
	 */
	public InitialMessageType getType() {
		return type;
	}
	
	@Override
	public String toString()
	{
		return "Init from " + getSenderId() + "-" + type.getInfo() + ": " + data;
	}
	
}
