package coloreti.util;

import java.util.Comparator;

/**
 * This is a utility class. How often did you wish Java had a class to represent
 * a single pair? Really often. That's what this class is for. Plus, it's generic
 * so you can pretty much do whatever you want with it.
 */
public class Pair<A, B> {
	
	public A a;
	public B b;
	
	public Pair(A a, B b)
	{
		this.a = a;
		this.b = b;
	}
	
	public A getA()
	{
		return a;
	}
	
	public B getB()
	{
		return b;
	}
	
	public void setA(A a)
	{
		this.a = a;
	}
	
	public void setB(B b)
	{
		this.b = b;
	}
	
	public static <A, B> Comparator<Pair<A, B>> getComparatorByA()
	{
		return new Comparator<Pair<A, B>>() 
		{
			public int compare(Pair<A, B> pairA, Pair<A, B> pairB)
			{
				return ((Comparable)pairA.a).compareTo((Comparable)pairB.a);
			}
		};		
	}
	
	public static <A, B> Comparator<Pair<A, B>> getComparatorByB()
	{
		return new Comparator<Pair<A, B>>() 
		{
			public int compare(Pair<A, B> pairA, Pair<A, B> pairB)
			{
				return ((Comparable)pairA.b).compareTo((Comparable)pairB.b);
			}
		};		
	}
	
	public boolean equals(Object o)
	{
		if (!(o instanceof Pair))
		{
			return false;
		}
		
		Pair<A, B> pair = (Pair<A, B>) o;
		if ((a == null && pair.a != null) || (b == null && pair.b != null))
		{
			return false;
		}
		return a.equals(pair.a) && b.equals(pair.b);
	}
	
	public int hashCode()
	{
		int aHash = (a == null) ? 43792812 : a.hashCode();
		int bHash = (b == null) ? 983742965 : b.hashCode();
		return aHash ^ bHash;
	}
}
